%%
%% Copyright (C) 2005-2024 AFPC
%%
%% Créateurs de la classe (en 2005):
%% Christine Solnon, Narendra Jussien et Romuald Debruyne
%%
%% Modifications apportées chaque année par les organisateurs des JFPC.
%%
%% Ce fichier peut-être distribué et/ou modifié:
%%
%% 1. sous les conditions de la "LaTeX Project Public License" et/ou
%% 2. sour les conditions de la  "GNU Public License".
%%
%% This file may be distributed and/or modified
%%
%% 1. under the LaTeX Project Public License and/or
%% 2. under the GNU Public License.

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{jfpc}[2018/11/19 v1.3 style class for JFPC proceedings]

\LoadClass[twoside,twocolumn,a4paper]{article}

\usepackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{lmodern}
\RequirePackage{graphicx}
\RequirePackage{grffile}
\RequirePackage{calc}
\RequirePackage[left,modulo]{lineno}
\RequirePackage[american,french]{babel}
\RequirePackage{microtype}

\DeclareOption{linenumbers}{%
  \setlength\linenumbersep{0.15cm}
  \renewcommand\linenumberfont{\normalfont\tiny\sffamily}
  \linenumbers
}
\ProcessOptions

\setlength{\topmargin}{0mm}
\setlength{\headheight}{00mm}
\setlength{\headsep}{10mm}
\setlength{\textwidth}{170mm}
\setlength{\textheight}{230mm}
\setlength{\oddsidemargin}{1.5mm}
\setlength{\evensidemargin}{-9.5mm}

\pagestyle{empty}

\def\@lannee{\the\year}
\newcommand{\annee}[1]{\def\@lannee{#1}}

\def\@letitre{d{\'e}finir le titre}
% \def\letitrecourt{\letitre}
\newcommand{\titre}[1]{\def\@letitre{#1}}
\renewcommand{\title}[1]{\titre{#1}}

\def\@lesauteurs{donner les auteurs}
\newcommand{\auteurs}[1]{\def\@lesauteurs{#1}}
\renewcommand{\author}[1]{\auteurs{#1}}

\def\@lesinstitutions{pr{\'e}ciser les institutions}
\newcommand{\institutions}[1]{\def\@lesinstitutions{#1}}

\def\@lesmels{pr{\'e}ciser les mails}
\newcommand{\mels}[1]{\def\@lesmels{#1}}

\date{}
\renewcommand\date[1]{}

\setlength\columnsep{15\p@}
\setlength\columnseprule{0\p@}

\renewcommand\and{\hfil}

\renewcommand\section{\@startsection {section}{1}{\z@}%
  {-3.5ex \@plus -1ex \@minus -.2ex}%
  {2.3ex \@plus.2ex}%
  {\normalfont\sffamily\large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
  {-3.25ex\@plus -1ex \@minus -.2ex}%
  {1.5ex \@plus .2ex}%
  {\normalfont\sffamily\normalsize\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
  {-3.25ex\@plus -1ex \@minus -.2ex}%
  {1.5ex \@plus .2ex}%
  {\normalfont\sffamily\normalsize\bfseries}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
  {3.25ex \@plus1ex \@minus.2ex}%
  {-1em}%
  {\normalfont\sffamily\normalsize\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
  {3.25ex \@plus1ex \@minus .2ex}%
  {-1em}%
  {\normalfont\sffamily\normalsize\bfseries}}

\newenvironment{resumeenv}
{\list{}{\listparindent 1.5em%
    \itemindent \listparindent%
    \leftmargin 1em%
    \rightmargin 1em%
    \parsep \z@ \@plus\p@}%
\item\relax}
{\endlist}

\newenvironment{resume}{\hfil \sffamily \textbf{R{\'e}sum{\'e}} \hfil \begin{resumeenv}\small}{\end{resumeenv}}
\renewenvironment{abstract}{\hfil \sffamily\textbf{Abstract} \hfil \begin{resumeenv}\selectlanguage{american}\small}{\end{resumeenv}}

\def\@title{%
  {\footnotesize\itshape\sffamily Actes JFPC \@lannee}%
  \hfill
  \rule[0.5ex]{\linewidth-25mm}{0.3mm}\\
  \vspace{3mm}
  {\huge\bfseries\sffamily\@letitre}
  \rule{\linewidth}{0.3mm}
}


\def\@author{%
  \textbf{\@lesauteurs }\\[1ex]
  \@lesinstitutions \\
  \texttt{\@lesmels}%
}

\newcommand\creationEntete{\maketitle\thispagestyle{empty}}

\newcommand\apetudiant[1]{#1\footnote{Papier doctorant : #1 est auteur principal.}}

\bibliographystyle{plain-fr}
